//! Simple Interactive Shell for AIOS v2

/// Shell buffer for command input
static mut INPUT_BUFFER: [u8; 64] = [0; 64];
static mut INPUT_POS: usize = 0;
static mut SHELL_ROW: usize = 12;

/// Initialize shell
pub fn init() {
    crate::print_str("aios> ", 0, unsafe { SHELL_ROW });
}

/// Process a character input
pub fn process_char(c: u8) {
    unsafe {
        match c {
            b'\n' => {
                // Execute command
                execute_command();
                new_prompt();
            }
            8 => {
                // Backspace
                if INPUT_POS > 0 {
                    INPUT_POS -= 1;
                    INPUT_BUFFER[INPUT_POS] = 0;
                    redraw_line();
                }
            }
            32..=126 => {
                // Printable character
                if INPUT_POS < INPUT_BUFFER.len() - 1 {
                    INPUT_BUFFER[INPUT_POS] = c;
                    INPUT_POS += 1;
                    crate::print_char(c, 6 + INPUT_POS - 1, SHELL_ROW);
                }
            }
            _ => {}
        }
    }
}

/// Execute the current command
fn execute_command() {
    unsafe {
        let cmd = core::str::from_utf8(&INPUT_BUFFER[..INPUT_POS]).unwrap_or("");
        
        SHELL_ROW += 1;
        
        match cmd {
            "help" => {
                crate::print_str("Commands: help, version, echo, clear", 0, SHELL_ROW);
                SHELL_ROW += 1;
            }
            "version" => {
                crate::print_str("AIOS v2.0 - Interactive Shell", 0, SHELL_ROW);
                SHELL_ROW += 1;
            }
            "echo" => {
                crate::print_str("Hello from interactive shell!", 0, SHELL_ROW);
                SHELL_ROW += 1;
            }
            "clear" => {
                crate::clear_screen();
                SHELL_ROW = 5;
                crate::print_str("AIOS v2 - AI Operating System", 25, 2);
                crate::print_str("Interactive Shell Active", 27, 3);
            }
            "" => {
                // Empty command, just new line
            }
            _ => {
                crate::print_str("Unknown command: ", 0, SHELL_ROW);
                crate::print_str(cmd, 18, SHELL_ROW);
                SHELL_ROW += 1;
            }
        }
        
        // Clear input buffer
        INPUT_BUFFER.fill(0);
        INPUT_POS = 0;
    }
}

/// Start a new command prompt
fn new_prompt() {
    unsafe {
        if SHELL_ROW >= 24 {
            SHELL_ROW = 23;
        }
        SHELL_ROW += 1;
        crate::print_str("aios> ", 0, SHELL_ROW);
    }
}

/// Redraw current input line
fn redraw_line() {
    unsafe {
        // Clear line after prompt
        for i in 6..80 {
            crate::print_char(b' ', i, SHELL_ROW);
        }
        
        // Redraw input
        for (i, &c) in INPUT_BUFFER[..INPUT_POS].iter().enumerate() {
            crate::print_char(c, 6 + i, SHELL_ROW);
        }
    }
}